pub const MANIFEST_FILE_NAME: &str = "Forc.toml";
pub const LOCK_FILE_NAME: &str = "Forc.lock";
pub const TEST_MANIFEST_FILE_NAME: &str = "Cargo.toml";
pub const TEST_DIRECTORY: &str = "tests";
pub const SWAY_EXTENSION: &str = "sw";
pub const USER_FORC_DIRECTORY: &str = ".forc";
pub const SRC_DIR: &str = "src";
pub const DEFAULT_NODE_URL: &str = "http://127.0.0.1:4000";
pub const LANGUAGE_NAME: &str = "Sway";
pub const STORAGE_DOMAIN_SEPARATOR: &str = "storage_";
pub const LIB_ENTRY: &str = "lib.sw";
pub const MAIN_ENTRY: &str = "main.sw";
